dofile_once("mods/flandre_player_character/flandre_config.lua") -- This file is where you can toggle certain options.

ModDevGenerateSpriteUVsForDirectory( "data/enemies_gfx/" )
dofile( "data/scripts/perks/perk.lua" )
dofile( "data/scripts/perks/perk_list.lua" )

function OnPlayerSpawned( player_entity ) -- this runs when player entity has been created

	if tonumber(StatsGetValue("playtime")) > 1 then -- this stops the mod from giving perks everytime you load your save
		return
	end

	local x,y = EntityGetTransform( player_entity )
	SetRandomSeed( x + 344, y - 523 )
	
	if EYE_GLOW == true then
		EntityAddComponent( player_entity, "SpriteComponent",
		{ 
			_tags="character",  
			alpha="1",
			image_file="mods/flandre_player_character/files/enemies_gfx/player_emissive.xml",
			emissive="1",
			additive="0",
			next_rect_animation="",
			offset_x="6",
			offset_y="14", 
			rect_animation="walk",
			z_index="0.5"
		} )
	end


	--Replaces the jetpack's particles (Fixed again, thanks x2 to Creme_Brulee)
	
	if JETPACK_TOGGLE == true then
		EntitySetComponentsWithTagEnabled( player_entity, "jetpack", 1 )
		if( nil == EntityGetFirstComponent( player_entity, "ParticleEmitterComponent", "flandre_lev" ) ) then
			-- Remove old particles
			for i,compo in ipairs( {"ParticleEmitterComponent", "SpriteParticleEmitterComponent"} ) do
				while( compo ~= nil ) do
					local ptEmit = EntityGetFirstComponent( player_entity, compo, "jetpack" )
					if ( ptEmit == nil ) then break end
					EntityRemoveComponent( player_entity, ptEmit )
				end
			end
			-- Create new particles
			local ptEmit1 = EntityAddComponent( player_entity, "ParticleEmitterComponent",
			{
				_tags="jetpack,flandre_lev",
				emitted_material_name="neon_tube_blood_red",
				x_pos_offset_min="-3",
				x_pos_offset_max="3",
				y_pos_offset_min="-3",
				y_pos_offset_max="3",
				x_vel_min="-6",
				x_vel_max="6",
				y_vel_min="10",
				y_vel_max="25",
				count_min="4",
				attractor_force="0",
				lifetime_min="0.0",
				lifetime_max="8",
				create_real_particles="0",
				emit_cosmetic_particles="1",
				fade_based_on_lifetime="1",
				draw_as_long="1",
				emission_interval_min_frames="1",
				emission_interval_max_frames="1",
				is_trail="0",
				trail_gap="0.0",
				airflow_force="1.051",
				airflow_time="1.01",
				airflow_scale="0.05",
				is_emitting="1"
			} )
			local ptx, pty = ComponentGetValueVector2( ptEmit1, "gravity" )
			local amn, amx = ComponentGetValueVector2( ptEmit1, "area_circle_radius" )
			pty = "6.0"
			amx = "0"
			ComponentSetValueVector2( ptEmit1, "gravity", ptx, pty )
			ComponentSetValueVector2( ptEmit1, "offset", "-2", "2" )
			ComponentSetValueVector2( ptEmit1, "area_circle_radius", amn, amx )
		end
	end

	
--[[ list of perk ids ]]--
--[[
1   CRITICAL_HIT
2   BREATH_UNDERWATER
3   EXTRA_MONEY
4   EXTRA_MONEY_TRICK_KILL
5   HOVER_BOOST
6   MOVEMENT_FASTER
7   LOW_GRAVITY
8   SPEED_DIVER
9   STRONG_KICK
10  REPELLING_CAPE
11  EXPLODING_CORPSES
11  SAVING_GRACE
12  INVISIBILITY
13  GLOBAL_GORE
14  REMOVE_FOG_OF_WAR
15  VAMPIRISM
16  EXTRA_HP
17  HEARTS_MORE_EXTRA_HP
18  GLASS_CANNON
19  RESPAWN
21  WORM_ATTRACTOR
22  WORM_DETRACTOR
23  PROTECTION_FIRE
24  PROTECTION_RADIOACTIVITY
25  PROTECTION_EXPLOSION
26  PROTECTION_MELEE
27  PROTECTION_ELECTRICITY
28  TELEPORTITIS
29  STAINLESS_ARMOUR
30  EDIT_WANDS_EVERYWHERE
31  ABILITY_ACTIONS_MATERIALIZED
32  PROJECTILE_HOMING
33  PROJECTILE_HOMING_SHOOTER
34  FREEZE_FIELD
35  DISSOLVE_POWDERS
36  BLEED_SLIME
37  BLEED_OIL
38  SHIELD
39  REVENGE_EXPLOSION
40  REVENGE_TENTACLE
41  ATTACK_FOOT
42  PLAGUE_RATS
43  PROJECTILE_REPULSION
44  ELECTRICITY
45  ATTRACT_ITEMS
46  EXTRA_KNOCKBACK
47  LOWER_SPREAD
48  BOUNCE
49  MYSTERY_EGGPLANT
50  PERKS_LOTTERY
51  GENOME_MORE_HATRED
52  GENOME_MORE_LOVE
]]--

	if VAMPIRISM_START == true then
		local perk;
		for i,p in ipairs( perk_list ) do
			if (p.id == "VAMPIRISM") then -- change this name(id) to start with different perk
				perk = p;
				break
			end
		end
		
	local perk_entity = perk_spawn( x, y, perk.id )
		if ( perk_entity ~= nil ) then
			perk_pickup( perk_entity, player_entity, EntityGetName( perk_entity ), false, false )
			GamePrintImportant( GameTextGet( "$log_pickedup_perk", GameTextGetTranslatedOrNot( perk.ui_name ) ), perk.ui_description ) -- delete this line to remove in-game notification
		end
	end
	
			-- Removes cape
	local plyChildEnt = EntityGetAllChildren( player_entity )
		if ( plyChildEnt ~= nil ) then
			for i,childEntity in ipairs( plyChildEnt ) do
				if ( EntityGetName( childEntity ) == "cape" ) then
					EntityKill( childEntity )
				break
			end
		end
	end
--[[ uncomment the code below (remove two hyphens at the beginning of each row) to start the game with multiple perks ]]--
--[[Start of code to uncomment(uncomment below this)]]--

--	local perks = { -- add perk ids (in double quotes) below to add new perks at the start of the game
--    "PROTECTION_FIRE",
--    "PROTECTION_RADIOACTIVITY",
--    "PROTECTION_EXPLOSION",
--    "PROTECTION_MELEE",
--    "PROTECTION_ELECTRICITY"
--    }
--  for i,p in ipairs( perk_list ) do
--    for j,r in ipairs( perks ) do
--      if (p.id == r) then
--        local p_entity = perk_spawn( x, y, p.id )
--        if ( p_entity ~= nil ) then
--          perk_pickup( p_entity, player_entity, EntityGetName( p_entity ), false, false )
--        end
--        break
--      end
--    end
--	end

--[[End of code to uncomment(uncomment above this)]]--
end